# Changelog

## 0.0.2 (2025-10-04)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/bountylaboratories/python-sdk/compare/v0.0.1...v0.0.2)

### Chores

* configure new SDK language ([d4e6d6d](https://github.com/bountylaboratories/python-sdk/commit/d4e6d6d7a89f1706c81db5cf7013c01c14cd4e3e))
* update SDK settings ([b1baa49](https://github.com/bountylaboratories/python-sdk/commit/b1baa49ab531f863abd53d4ea0be0a9883f36894))
* update SDK settings ([9fc9b5b](https://github.com/bountylaboratories/python-sdk/commit/9fc9b5b30db13a0b3eedafd4e321f42c632758ec))
